@@ -10,6 +10,7 @@ from .arch_independent_structs import (
     DylibCommandStruct,
     MachoDyldChainedFixupsHeader,
     MachoDyldChainedImport,
+    MachoDyldChainedImportAddend,
     MachoDyldChainedImportAddend64,
     MachoDyldChainedPtr64Bind,
     MachoDyldChainedPtr64Rebase,
@@ -111,6 +112,11 @@ class DyldInfoParser:
             chained_import_struct = MachoDyldChainedImport
             compute_library_ordinal = DyldInfoParser._compute_library_ordinal_for_chained_import_type
 
+        elif imports_format == MachoDyldChainedImportFormat.DYLD_CHAINED_IMPORT_ADDEND:
+            # com.jpmorgan.intelligence-uat-ent includes ADDEND imports, but we can't include a test case in this tree.
+            chained_import_struct = MachoDyldChainedImportAddend
+            compute_library_ordinal = DyldInfoParser._compute_library_ordinal_for_chained_import_type
+
         elif imports_format == MachoDyldChainedImportFormat.DYLD_CHAINED_IMPORT_ADDEND64:
             # net.salkosuo.clp.ttmsg includes ADDEND64 imports, but the binary is too big to include in the test tree.
             # TODO(PT): This same binary contains imports with an ordinal of BIND_SPECIAL_DYLIB_WEAK_LOOKUP (-3),
